@@ -586,9 +586,14 @@ replace_daemon_at (const gchar *directory)
 {
 	gboolean ret;
 
-	g_free (control_directory);
-	control_directory = g_strdup (directory);
-	ret = gkd_control_quit (directory);
+	/*
+	 * The first control_directory is the environment one, always
+	 * prefer that since it's the one that ssh and gpg will connect to
+	 */
+	if (control_directory == NULL)
+		control_directory = g_strdup (directory);
+
+	ret = gkd_control_quit (directory, GKD_CONTROL_QUIET_IF_NO_PEER);
 
 	/*
 	 * If we quit, wait a short time before initializing so the other
@@ -597,7 +602,13 @@ replace_daemon_at (const gchar *directory)
 	if (ret == TRUE)
 		g_usleep (200 * 1000); /* 200 ms in us */
 
-	return ret;
+	/*
+	 * Note that we don't return TRUE, since we want to quit all the
+	 * running daemons (for this session) that may have been started
+	 * by dbus or elsewhere.
+	 */
+
+	return FALSE;
 }
 
 typedef gboolean (*DiscoverFunc) (const gchar *control_directory);
@@ -946,7 +957,9 @@ main (int argc, char *argv[])
 	} else if (run_for_replace) {
 		discover_other_daemon (replace_daemon_at, FALSE);
 		if (control_directory)
-			g_message ("replacing daemon at: %s", control_directory);
+			g_message ("Replacing daemon, using directory: %s", control_directory);
+		else
+			g_message ("Could not find daemon to replace, staring normally");
 	}
 
 	/* Initialize the main directory */
